@@ -1,9 +1,9 @@
 #########
 # Author:        rmp
-# Last Modified: $Date: 2010-10-28 17:09:19 +0100 (Thu, 28 Oct 2010) $
-# Id:            $Id: Expr.pm 19 2010-10-28 16:09:19Z zerojinx $
+# Last Modified: $Date$
+# Id:            $Id$
 # Source:        $Source$
-# $HeadURL: https://text-sass.svn.sourceforge.net/svnroot/text-sass/trunk/lib/Text/Sass/Expr.pm $
+# $HeadURL$
 #
 package Text::Sass::Expr;
 use strict;
@@ -69,9 +69,6 @@ our $CONV = {
 sub expr {
   my ($pkg, $part1, $op, $part2) = @_;
 
-  $part1 =~ s/[#](.)(.)(.)(\b)/#${1}${1}${2}${2}${3}${3}$4/smxgi;
-  $part2 =~ s/[#](.)(.)(.)(\b)/#${1}${1}${2}${2}${3}${3}$4/smxgi;
-
   my ($p1, $u1) = @{$pkg->units($part1)};
   my ($p2, $u2) = @{$pkg->units($part2)};
 
@@ -148,7 +145,7 @@ Text::Sass::Expr
 
 =head1 VERSION
 
-$LastChangedRevision: 19 $
+$LastChangedRevision$
 
 =head1 SYNOPSIS
 
